# -*- coding: utf-8 -*-
"""favicon
:copyright: (c) 2019 by Scott Werner.
:license: MIT, see LICENSE for more details.
"""
from .favicon import Icon, get

__all__ = ["get", "Icon"]

__title__ = "favicon"
__version__ = "0.7.0"
__author__ = "Scott Werner"
__license__ = "MIT"
__copyright__ = "Copyright 2019 Scott Werner"
